local _, class = UnitClass("player");
if (class ~= "WARRIOR" and class ~= "DRUID" and class ~= "DEATHKNIGHT") then
	return;
end

local plugin = InfoPanel.AddPlugin();

--------------------------------------------------------------------------------------------------------
--                                               Calcs                                                --
--------------------------------------------------------------------------------------------------------

local function GetDamageReduction(ignoreStance)
	local playerLevel = UnitLevel("player");
	local _, effectiveArmor = UnitArmor("player");
	local damageReduction = PaperDollFrame_GetArmorReduction(effectiveArmor,playerLevel);
	local stance = GetShapeshiftForm();
	if (stance) and (stance == 1 or stance == 2) and (not ignoreStance) then
		local stanceMod = (stance == 1 and 0.95 or stance == 2 and 0.9);
		damageReduction = (1 - (1 - damageReduction / 100) * stanceMod) * 100;
	end
	return damageReduction;
end

local function GetMissChance()
	local playerLevel = UnitLevel("player");
	local baseDefense, armorDefense = UnitDefense("player");
	return ((baseDefense + armorDefense - playerLevel * 5) * 0.04 + 5);
end

local function GetTotalAvoidance()
	return (GetDodgeChance() + GetParryChance() + GetMissChance());
end

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	local _, effectiveArmor = UnitArmor("player");

	tooltip:AddLine("Defense Info",1,1,1);
	tooltip:AddDoubleLine("Armor",effectiveArmor,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Reduction",format("%.2f%%",GetDamageReduction(1)),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Effective Reduction",format("%.2f%%",GetDamageReduction()),nil,nil,nil,1,1,1);

	tooltip:AddLine(" ");
	tooltip:AddLine("Avoidance",1,1,1);
	tooltip:AddDoubleLine("Miss Chance",format("%.2f%%",GetMissChance()),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Dodge Chance",format("%.2f%%",GetDodgeChance()),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Parry Chance",format("%.2f%%",GetParryChance()),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Total",format("%.2f%%",GetTotalAvoidance()),nil,nil,nil,0,1,0);

	tooltip:AddLine(" ");
	tooltip:AddLine("Block",1,1,1);
	tooltip:AddDoubleLine("Block",format("%.2f%%",GetBlockChance()),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Block Value",GetShieldBlock(),nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Block + Avoidance",format("%.2f%%",GetBlockChance() + GetTotalAvoidance()),nil,nil,nil,1,1,1);
end

local function OnClick(self,button)
	local editBox = ChatEdit_GetActiveWindow();
	if (editBox) and (editBox:IsVisible()) then
		editBox:Insert("n/a");
	end
end

local function OnEvent(self,event,p1,...)
	if (event == "UNIT_AURA") and (p1 ~= "player") then
		return;
	end
	-- Armor/Avoidance/BlockVal
	self:SetText("|cffffffff%.2f%%  |cff80c0ff%.2f%%",GetDamageReduction(),GetTotalAvoidance());
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin.icon:SetTexture("Interface\\Icons\\Ability_Warrior_DefensiveStance");
plugin:SetScript("OnEvent",OnEvent);
plugin:SetScript("OnClick",OnClick);
plugin:RegisterEvent("PLAYER_LOGIN");
plugin:RegisterEvent("COMBAT_RATING_UPDATE");
plugin:RegisterEvent("PLAYER_DAMAGE_DONE_MODS");
plugin:RegisterEvent("UNIT_AURA");