local plugin = InfoPanel.AddPlugin();
local sessionHonor, honorThisZone, honorPrevZone;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	tooltip:AddLine("Honor Details",1,1,1);
	local kills, points = GetPVPSessionStats();
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	local _, arenaPts = GetCurrencyInfo(CONQUEST_CURRENCY);
	-- Session/Zone Honor
	tooltip:AddDoubleLine("This Session's Honor",honorPts - sessionHonor,nil,nil,nil,1,1,1);
	if (honorThisZone) then
		tooltip:AddDoubleLine("This Zone's Honor",points - honorThisZone,nil,nil,nil,1,1,1);
		if (honorPrevZone) then
			tooltip:AddDoubleLine("Last Zone's Honor",honorThisZone - honorPrevZone,nil,nil,nil,1,1,1);
		end
		tooltip:AddLine(" ");
	end
	-- Today's values
	tooltip:AddDoubleLine("Today's Kills",kills,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Today's Points",points,nil,nil,nil,1,1,1);
	tooltip:AddLine(" ");
	-- Yesterday's values
	kills, points = GetPVPYesterdayStats();
	tooltip:AddDoubleLine("Yesterday's Kills",kills,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Yesterday's Points",points,nil,nil,nil,1,1,1);
	tooltip:AddLine(" ");
	-- Lifetime stats
	local highestRank;
	kills, highestRank = GetPVPLifetimeStats();
	tooltip:AddDoubleLine("Lifetime Kills",kills,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Highest Rank",highestRank,nil,nil,nil,1,1,1);
	tooltip:AddLine(" ");
	-- Rank
	local rankName, rankNumber = GetPVPRankInfo(highestRank);
	if ( not rankName ) then
		rankName = NONE;
	end
	tooltip:AddDoubleLine("Rank Name",rankName,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine("Rank Number",rankNumber,nil,nil,nil,1,1,1);
	tooltip:AddLine(" ");
	-- Points
	tooltip:AddDoubleLine(HONOR_POINTS,honorPts,nil,nil,nil,1,1,1);
	tooltip:AddDoubleLine(ARENA_POINTS,arenaPts,nil,nil,nil,1,1,1);
	-- Az: Wintergrasp wait time
	if (GetWintergraspWaitTime) then
		local timeLeft = GetWintergraspWaitTime();
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("Wintergrasp Time",type(timeLeft) == "number" and InfoPanel.FormatTime2(timeLeft) or UNKNOWN,nil,nil,nil,1,1,1);
	end
	-- PvP Time
	local pvpTime = GetPVPTimer();
	if (pvpTime) and (pvpTime < 301000) then
		tooltip:AddLine(" ");
		tooltip:AddDoubleLine("PvP Flag Time",InfoPanel.FormatTime(pvpTime / 1000),nil,nil,nil,1,1,1);
	end;
end

-- Zone Change
function plugin:ZONE_CHANGED_NEW_AREA(event)
	honorPrevZone = honorThisZone;
	local _, hp = GetPVPSessionStats();
	honorThisZone = hp;
end
plugin.PLAYER_ENTERING_WORLD = plugin.ZONE_CHANGED_NEW_AREA;

-- Honor Update
function plugin:CURRENCY_DISPLAY_UPDATE(event)
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	self:SetText(honorPts);
end

-- Login
function plugin:PLAYER_LOGIN(event)
	local _, honorPts = GetCurrencyInfo(HONOR_CURRENCY);
	sessionHonor = honorPts;
	self:SetText(honorPts);
	self[event] = nil;
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin.icon:SetTexture(UnitFactionGroup("player") == "Alliance" and "Interface\\Icons\\INV_BannerPVP_02" or "Interface\\Icons\\INV_BannerPVP_01");
plugin:SetScript("OnClick",function(self) ToggleFrame(PVPFrame); end);
plugin:RegisterEvent("PLAYER_LOGIN");

--plugin:RegisterEvent("HONOR_CURRENCY_UPDATE");
plugin:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
--plugin:RegisterEvent("KNOWN_CURRENCY_TYPES_UPDATE");

--plugin:RegisterEvent("PLAYER_ENTERING_WORLD");
plugin:RegisterEvent("ZONE_CHANGED_NEW_AREA");