local plugin = InfoPanel.AddPlugin();
local sessionStart = GetTime();
local moneyStart, moneyLast, moneyGain, moneyLoss;

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	local moneyNow = GetMoney();
	tooltip:AddLine("Money Info",1,1,1);
	tooltip:AddDoubleLine("Starting Money",InfoPanel.FormatCopper(moneyStart));
	if (moneyGain ~= 0) or (moneyLoss ~= 0) then
		local balanceText = (moneyNow > moneyStart) and "Gain" or "Loss";
		local moneyPerHour = (moneyNow - moneyStart) / ((GetTime() - sessionStart) / 60 / 60);
		tooltip:AddDoubleLine("Money Loss",InfoPanel.FormatCopper(moneyLoss));
		tooltip:AddDoubleLine("Money Gain",InfoPanel.FormatCopper(moneyGain));
		tooltip:AddDoubleLine("Money Profit "..balanceText,InfoPanel.FormatCopper(abs(moneyGain - moneyLoss)));
		tooltip:AddDoubleLine("Money "..balanceText.." / Hour",InfoPanel.FormatCopper(floor(abs(moneyPerHour))));
	end
end

-- OnClick
local function OnClick(self,button)
	local editBox = ChatEdit_GetActiveWindow();
	if (editBox) and (editBox:IsVisible()) then
		editBox:Insert(self.text:GetText():gsub("|c%x%x%x%x%x%x%x%x",""):gsub("|r",""));
	elseif (IsShiftKeyDown()) and (button == "RightButton") then
		sessionStart = GetTime();
		moneyStart = GetMoney();
		moneyLast = moneyStart;
		moneyGain, moneyLoss = 0, 0;
		if (GameTooltip:IsOwned(self)) then
			self:GetScript("OnEnter")(self);
		end
	end
end

-- Money Change
function plugin:PLAYER_MONEY(event)
	local moneyNow = GetMoney();
	local diff = (moneyNow - moneyLast);
	if (diff >= 0) then
		moneyGain = (moneyGain + diff);
	else
		moneyLoss = (moneyLoss - diff);
	end
	self:SetText(GetCoinTextureString(moneyNow,16));
	moneyLast = moneyNow;
end

-- Login
function plugin:PLAYER_LOGIN(event)
	moneyStart = GetMoney();
	moneyLast = moneyStart;
	moneyGain, moneyLoss = 0, 0;
	self:UnregisterAllEvents();
	self:RegisterEvent("PLAYER_MONEY");
	self[event] = nil;
	self:PLAYER_MONEY();
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin.icon:SetTexture("Interface\\Icons\\INV_Misc_Coin_01");
plugin:SetScript("OnClick",OnClick);
plugin:RegisterEvent("PLAYER_LOGIN");