local _G = getfenv(0);
local plugin = InfoPanel.AddPlugin();
local startRep, lastRep = {}, {};
local factionStandings = {};
local FACTION_COLORS = CUSTOM_FACTION_COLORS or FACTION_BAR_COLORS;

-- Rep History
local repHistory = {};
for i = 1, 20 do
	repHistory[i] = {};
end

--------------------------------------------------------------------------------------------------------
--                                          Helper Functions                                          --
--------------------------------------------------------------------------------------------------------

-- Splash Message
local function ScreenSplash(header,subtext,r,g,b)
	-- Set Header, Subtext and colors
	ZoneTextString:SetText(header);
	ZoneTextString:SetTextColor(r,g,b);
	SubZoneTextString:SetText(subtext);
	SubZoneTextString:SetTextColor(r,g,b);
	-- Clear this so it wont show: Alliance/Horde/Contested territory or Sanctuary
	PVPInfoTextString:SetText("");
	PVPArenaTextString:SetText("");
	-- Show Frames
	ZoneTextFrame.startTime = GetTime();
	ZoneTextFrame:Show();
	SubZoneTextFrame.startTime = GetTime();
	SubZoneTextFrame:Show();
end

--------------------------------------------------------------------------------------------------------
--                                             Functions                                              --
--------------------------------------------------------------------------------------------------------

-- OnShowTooltip
function plugin:OnShowTooltip(tooltip)
	-- Rep History
	if (IsShiftKeyDown()) then
		tooltip:AddLine("Reputation History",1,1,1);
		for i = 1, #repHistory do
			if (repHistory[i].factionName) then
				tooltip:AddDoubleLine(repHistory[i].factionName,repHistory[i].earnedValue,nil,nil,nil,1,1,1);
			end
		end
		return;
	end
	-- Init
	tooltip:AddLine("Reputation Info",1,1,1);
	wipe(factionStandings);
	local factionCount = 0;
	-- Scan Factions
	for i = 1, GetNumFactions() do
		local factionName, _, standingId, minValue, maxValue, earnedValue, _, _, isHeader, _, hasRep = GetFactionInfo(i);
		if (not isHeader) or (hasRep) then
			factionStandings[standingId] = (factionStandings[standingId] or 0) + 1;
			factionCount = (factionCount + 1);
		end
		if (startRep[factionName]) then
			local repChange = (earnedValue - startRep[factionName].earnedValue);
			if (repChange ~= 0) then
				repChange = ((repChange > 0 and "|cff80ff80+") or (repChange < 0 and "|cffff8080-") or "")..abs(repChange);
				tooltip:AddDoubleLine((isHeader and "|cffffffff- " or "")..factionName,repChange,nil,nil,nil,1,1,1);
			end
		end
	end
	-- Add Faction Standings
	if (tooltip:NumLines() > 1) then
		tooltip:AddLine(" ");
		tooltip:AddLine("Standings",1,1,1);
	end;
	tooltip:AddDoubleLine("Known Factions",factionCount,nil,nil,nil,1,1,1);
	for standing, factionCount in next, factionStandings do
		local color = FACTION_COLORS[standing];
		tooltip:AddDoubleLine(_G["FACTION_STANDING_LABEL"..standing],factionCount,nil,nil,nil,color.r,color.g,color.b);
	end
	-- Watched Faction
	local name, standing, min, max, value = GetWatchedFactionInfo();
	if (name) then
		tooltip:AddLine(" ");
		tooltip:AddLine(name,1,1,1);
		local color = FACTION_COLORS[standing];
		tooltip:AddDoubleLine(_G["FACTION_STANDING_LABEL"..standing],format("%d / %d",value - min,max - min),nil,nil,nil,color.r,color.g,color.b);
	end
end

-- OnClick
local function OnClick(self,button)
	local editBox = ChatEdit_GetActiveWindow();
	if (editBox) and (editBox:IsVisible()) then
		local name, standing, min, max, value = GetWatchedFactionInfo();
		if (name) then
			editBox:Insert(format("%s: %d / %d",name,value - min,max - min));
		else
			editBox:Insert("n/a");
		end
	else
		ToggleCharacter("ReputationFrame");
	end
end

-- Modifier Key Change -- Az: Bad hack, plugins should be able to request the core to update the tooltip
function plugin:MODIFIER_STATE_CHANGED(key,state)
	if (GameTooltip:IsOwned(self)) then
		self:GetScript("OnEnter")(self);
	end
end

-- Gather Info
function plugin:UPDATE_FACTION(event)
	-- Set initial Rep for factions not yet saved, as well as updating to most recent values
	for i = 1, GetNumFactions() do
		local factionName, _, standingId, _, _, earnedValue = GetFactionInfo(i);
		-- Init starting rep. Happens on login, as well as when you meet a new faction
		if (not startRep[factionName]) then
			startRep[factionName] = { earnedValue = earnedValue, standingId = standingId };
		end
		-- If we just met this faction, do not analyze it, just create the data table
		if (not lastRep[factionName]) then
			lastRep[factionName] = {};
		else
			-- Update rep history, unhappy with implementation of this
			if (lastRep[factionName].earnedValue ~= earnedValue) then
				for i = 1, #repHistory - 1 do
					repHistory[i].factionName = repHistory[i + 1].factionName;
					repHistory[i].earnedValue = repHistory[i + 1].earnedValue;
				end
				repHistory[#repHistory].factionName = factionName;
				repHistory[#repHistory].earnedValue = (earnedValue - lastRep[factionName].earnedValue);
			end
			-- Rep Standing *DING*
			if (lastRep[factionName].standingId ~= standingId) then
				local color = FACTION_COLORS[standingId];
				ScreenSplash(_G["FACTION_STANDING_LABEL"..standingId].."!",factionName,color.r,color.g,color.b);
			end
		end
		-- Update rep cache to current value
		lastRep[factionName].earnedValue = earnedValue;
		lastRep[factionName].standingId = standingId;
	end
	-- Update Rep
	local name, standing, min, max, value = GetWatchedFactionInfo();
	if (name) then
		local color = FACTION_COLORS[standing];
--		self:SetText(_G["FACTION_STANDING_LABEL"..standing].." - "..(value - min).."/"..(max - min));
		self:SetText(max - value);	-- show remaining rep until next standing
		plugin.text:SetTextColor(color.r,color.g,color.b);
	else
		self:SetText("Rep");
		plugin.text:SetTextColor(1,1,1);
	end;
end

--------------------------------------------------------------------------------------------------------
--                                              Finalize                                              --
--------------------------------------------------------------------------------------------------------

plugin.icon:SetTexture("Interface\\Icons\\Achievement_Reputation_01");
plugin:SetScript("OnClick",OnClick);
plugin:RegisterEvent("UPDATE_FACTION");
plugin:RegisterEvent("MODIFIER_STATE_CHANGED");